@@ -78,19 +78,18 @@ from lino.utils.xmlgen import html as xghtml
 
 from lino_welfare.modlib.pcsw import models as pcsw
 
-try:
+#~ try:
   
-    import suds
-    from suds.client import Client
-    from suds.transport.http import HttpAuthenticated
-    from suds.transport.http import HttpTransport
-    from suds.sax.element import Element as E
-    from suds.sax.parser import Parser
-    PARSER = Parser()
-
-except ImportError, e:
-    pass
+import suds
+from suds.client import Client
+from suds.transport.http import HttpAuthenticated
+from suds.transport.http import HttpTransport
+from suds.sax.element import Element as E
+from suds.sax.parser import Parser
+PARSER = Parser()
 
+#~ except ImportError, e:
+    #~ pass
 
 
 countries = dd.resolve_app('countries')
@@ -1773,7 +1772,7 @@ def setup_site_cache(self,force):
     def make_wsdl(template,parts):
         fn = os.path.join(settings.MEDIA_ROOT,*parts) 
         if not force and os.path.exists(fn):
-            if os.stat(fn).st_mtime > self.mtime:
+            if os.stat(fn).st_mtime > self.ui.mtime:
                 logger.info("NOT generating %s because it is newer than the code.",fn)
                 return
         s = file(os.path.join(os.path.dirname(__file__),'WSDL',template)).read()
