@@ -35,7 +35,7 @@ from lino import mixins
 from lino.utils import i2d, Cycler
 from lino.utils.instantiator import Instantiator
 from lino.core.dbutils import resolve_model
-from north.babel import babel_values
+from north.dbutils import babel_values
 from lino.utils.restify import restify
 from lino.utils import dblogger
 #~ from lino.models import update_site_config
@@ -415,7 +415,7 @@ def objects():
     yield role(company=cpas,person=gerd,type=4)
     #~ yield link(a=cpas,b=gerd,type=4)
     
-    # see :doc:`/blog/2011/1007`
+    # see :blogentry:`20111007`
     tatjana = client(
         first_name=u"Tatjana",last_name=u"Kasennova",
         #~ first_name=u"Татьяна",last_name=u"Казеннова",
@@ -685,10 +685,13 @@ def objects():
           sector=SECTORS.pop(),function=f)
     
     JOBS = Cycler(jobs.Job.objects.all())
+    CSTATES = Cycler(jobs.CandidatureStates.objects())
         
-    for i in range(30):
-        yield jobs.Candidature(job=JOBS.pop(),person=CLIENTS.pop(),
-          date_submitted=settings.SITE.demo_date(-30+i))
+    for i in range(40):
+        yield jobs.Candidature(job=JOBS.pop(),
+          person=CLIENTS.pop(),
+          state=CSTATES.pop(),
+          date_submitted=settings.SITE.demo_date(-40+i))
     
 
     
