@@ -40,10 +40,10 @@ from django.core.exceptions import ValidationError
 
 from lino import dd
 from lino.utils import i2d
-from north import babel
+#~ from north import babel
 #~ from lino.core.dbutils import resolve_model
 #Companies = resolve_model('contacts.Companies')
-from lino.utils.test import TestCase
+from djangosite.utils.test import TestCase
 
 contacts_RoleType = dd.resolve_model('contacts.RoleType')
 contacts_Role = dd.resolve_model('contacts.Role')
@@ -92,7 +92,7 @@ def test01(self):
     """
     Tests error handling when printing a contract whose type's 
     name contains non-ASCII char.
-    Created :doc:`/blog/2011/0615`.
+    Created :blogref:`20110615`.
     See the source code at :srcref:`/lino/apps/pcsw/tests/pcsw_tests.py`.
     """
     
@@ -112,7 +112,8 @@ def test01(self):
     self.assertEqual(self.jobs_contract_1.company,self.job_provider)
     
     
-    if 'en' in babel.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('en'):
+    #~ if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
         url = '/api/jobs/Contract/1?an=do_print'
         response = self.client.get(url,REMOTE_USER='root',HTTP_ACCEPT_LANGUAGE='en')
         result = self.check_json_result(response,'success message alert')
@@ -201,7 +202,7 @@ def test03(self):
     """
     Testing whether `/api/notes/NoteTypes/1?fmt=json` 
     has no item `templateHidden`.
-    Created :doc:`/blog/2011/0509`.
+    Created :blogref:`20110509`.
     See the source code at :srcref:`/lino/apps/pcsw/tests/pcsw_tests.py`.
     """
     from lino.modlib.notes.models import NoteType
@@ -245,7 +246,7 @@ def test03(self):
 def test04(self):
     """
     Test some features used in document templates.
-    Created :doc:`/blog/2011/0615`.
+    Created :blogref:`20110615`.
     See the source code at :srcref:`/lino/apps/pcsw/tests/pcsw_tests.py`.
     """
     from lino.dd import Genders
@@ -265,8 +266,9 @@ def test04(self):
     p.full_clean()
     p.save()
     
-    if 'fr' in babel.AVAILABLE_LANGUAGES:
-        babel.set_language('fr')
+    #~ if 'fr' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('fr'):
+        dd.set_language('fr')
         #~ self.assertEqual(p.get_titled_name,"Mr Jean Louis DUPONT")
         self.assertEqual(p.full_name,"M. Jean Louis DUPONT")
         self.assertEqual('\n'.join(p.address_lines()),u"""\
@@ -276,7 +278,7 @@ Bruxelles
 Belgique""")
     
     
-    babel.set_language(None)
+    dd.set_language(None)
         
         
 def test05(self):
@@ -284,7 +286,7 @@ def test05(self):
     obj2str() caused a UnicodeDecodeError when called on an object that had 
     a ForeignKey field pointing to another instance whose __unicode__() 
     contained non-ascii characters.
-    See :doc:`/blog/2011/0728`.
+    See :blogref:`20110728`.
     """
     a = pcsw.Activity(name=u"Sozialhilfeempfänger")
     p = pcsw.Client(last_name="Test",activity=a)
@@ -298,7 +300,7 @@ def test05(self):
     a.save()
     self.assertEqual(dd.obj2str(a,True),"Activity(id=1,name='Sozialhilfeempf\\xe4nger')")
     
-    expected = "Client(language='%s'," % babel.DEFAULT_LANGUAGE
+    expected = "Client(language='%s'," % settings.SITE.DEFAULT_LANGUAGE.django_code
     expected += "last_name='Test'"
     expected += ",client_state=ClientStates.newcomer:10"
     #~ expected += ",is_active=True"
@@ -312,7 +314,7 @@ def test05(self):
     
 def test06(self):
     """
-    :doc:`/blog/2011/1003`.
+    :blogref:`20111003`.
     The `id` field of a Company or Person was never disabled 
     because Lino didn't recognize it as the primary key.
     
